Index: /trunk/src/VBox/Additions/x11/Installer/x11config.sh
===================================================================
--- /trunk/src/VBox/Additions/x11/Installer/x11config.sh	(revision 46562)
+++ /trunk/src/VBox/Additions/x11/Installer/x11config.sh	(revision 46563)
@@ -15,5 +15,5 @@
 
 auto_mouse=""
-new_mouse=""
+auto_keyboard=""
 no_bak=""
 old_mouse_dev="/dev/psaux"
@@ -56,4 +56,5 @@
     kbd_drv="`cat "$cfg" | sed -n -e "/$KBD_SECTION/,/$END_SECTION/p" |
              sed -n -e "0,/$DRIVER_KBD/s/$DRIVER_KBD/\\1/p"`"
+    test -z "${kbd_drv}" && test -z "${auto_keyboard}" && kbd_drv=keyboard
     cat > "$tmp" << EOF
 # VirtualBox generated configuration file
@@ -70,31 +71,7 @@
 EndSection
 EOF
-    kbd_layout=""
-    test -n "$kbd_drv" && kbd_layout='  InputDevice  "Keyboard[0]" "CoreKeyboard"'
-    test -z "$auto_mouse" -a -z "$new_mouse" && cat >> $tmp << EOF
-
-Section "InputDevice"
-  Identifier  "Mouse[1]"
-  Driver      "vboxmouse"
-  Option      "Buttons" "9"
-  Option      "Device" "$old_mouse_dev"
-  Option      "Name" "VirtualBox Mouse"
-  Option      "Protocol" "explorerps/2"
-  Option      "Vendor" "Oracle Corporation"
-  Option      "ZAxisMapping" "4 5"
-  Option      "CorePointer"
-EndSection
-
-Section "ServerLayout"
-  Identifier   "Layout[all]"
-$kbd_layout
-  InputDevice  "Mouse[1]" "CorePointer"
-  Option       "Clone" "off"
-  Option       "Xinerama" "off"
-  Screen       "Screen[0]"
-EndSection
-EOF
-
-    test -z "$auto_mouse" -a -n "$new_mouse" &&
+    kbd_line=""
+    test -n "$kbd_drv" && kbd_line='  InputDevice  "Keyboard[0]" "CoreKeyboard"'
+    test -z "$auto_mouse" &&
         cat >> "$tmp" << EOF
 
@@ -122,5 +99,5 @@
 Section "ServerLayout"
   Identifier   "Layout[all]"
-  InputDevice  "Keyboard[0]" "CoreKeyboard"
+${kbd_line}
   InputDevice  "Mouse[1]" "CorePointer"
   InputDevice  "Mouse[2]" "SendCoreEvents"
@@ -166,6 +143,6 @@
         --autoMouse)
             auto_mouse=1 ;;
-        --newMouse)
-            new_mouse=1 ;;
+        --autoKeyboard)
+            auto_keyboard=1 ;;
         --noBak)
             no_bak=1 ;;

Index: /trunk/src/VBox/Additions/linux/installer/vboxadd-x11.sh
===================================================================
--- /trunk/src/VBox/Additions/linux/installer/vboxadd-x11.sh	(revision 46562)
+++ /trunk/src/VBox/Additions/linux/installer/vboxadd-x11.sh	(revision 46563)
@@ -285,7 +285,7 @@
     # By default, we want to run our xorg.conf setup script
     setupxorgconf="true"
-    # On all but the oldest X servers we want to use our new mouse
-    # driver.
-    newmouse="--newMouse"
+    # All but the oldest supported X servers can automatically set up the
+    # keyboard driver.
+    autokeyboard="--autoKeyboard"
     # On more recent servers our kernel mouse driver will be used
     # automatically
@@ -410,4 +410,5 @@
             vboxmouse_src=vboxmouse_drv.o
             automouse=""
+            autokeyboard=""  # Actually not true for 6.8, but it doesn't matter.
             ;;
         * )
@@ -459,5 +460,5 @@
                         generated="$generated  `printf "$i\n"`"
                     else
-                        "$lib_dir/x11config.sh" $newmouse $automouse $nopsaux "$i"
+                        "$lib_dir/x11config.sh" $autokeyboard $automouse $nopsaux "$i"
                     fi
                     configured="true"
@@ -473,5 +474,5 @@
             if test -z "$configured"; then
                 touch "$main_cfg"
-                "$lib_dir/x11config.sh" $newmouse $automouse $nopsaux --noBak "$main_cfg"
+                "$lib_dir/x11config.sh" $autokeyboard $automouse $nopsaux --noBak "$main_cfg"
                 touch "$nobak"
             fi